@@ -7,7 +7,7 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2009 Ralph Amissah All Rights Reserved.
+ * Copyright: (C) 1997 - 2010, Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -354,7 +354,8 @@ module SiSU_HTML_seg
             para=format_seg.no_paranum
           end
         end
-        if para[/#{Mx[:id_o]}~(\d+;(?:[ohmu]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp)#{Mx[:id_c]}$/]
+        m=/#{Mx[:id_o]}~(\d+;(?:[ohmu]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp)#{Mx[:id_c]}$/
+        if para =~m
           @sto=SiSU_HTML::Source::Split_text_object.new(@md,para).html_seg
           if @sto.format =~/i[1-9]|ordinary/ #watch
             txt_obj={:txt =>@sto.text}
@@ -393,7 +394,9 @@ module SiSU_HTML_seg
           @sto=nil
           table=SiSU_HTML_shared::Table.new(para)
           para=table.table
-        else @sto=nil
+        else
+          para.gsub!(/#{Mx[:gl_bullet]}/,'●&nbsp;&nbsp;') #watch
+          @sto=nil
         end
         if @md.flag_separate_endnotes
           para.gsub!(/"\s+href="#_(\d+)">/,%{" href=\"endnotes#{Sfx[:html]}#_\\1">})       #endnote- twice #removed file type
