@@ -150,19 +150,19 @@ module SiSU_document_structure_extract
           when /^:?([A-C1-6])\~/                           #heading / lv
             lv=$1
             ln=ln_get(lv)
-            t_o=if t_o=~/^:?[A-C1-6]\~\s+(.+)/
+            t_o=if t_o=~/^:?[A-C1-6]\~\s+(.+)/m
               obj=$1
               note=endnote_test?(obj)
               obj,tags=extract_tags(obj)
               h={:lv=>lv,:ln=>ln,:obj=>obj,:idx=>idx,:tags=>tags}
               SiSU_document_structure::Object_heading.new.heading(h)
-            elsif t_o=~/^:?[A-C1-6]\~(\S+?)-\s+(.+)/
+            elsif t_o=~/^:?[A-C1-6]\~(\S+?)-\s+(.+)/m
               name,obj=$1,$2
               note=endnote_test?(obj)
               obj,tags=extract_tags(obj)
               h={:lv=>lv,:name=>name,:obj=>obj,:idx=>idx,:autonum_=>false,:tags=>tags}
               SiSU_document_structure::Object_heading.new.heading(h)
-            elsif t_o=~/^:?[A-C1-6]\~(\S+)\s+(.+)/
+            elsif t_o=~/^:?[A-C1-6]\~(\S+)\s+(.+)/m
               name,obj=$1,$2
               note=endnote_test?(obj)
               obj,tags=extract_tags(obj,name)
@@ -171,7 +171,7 @@ module SiSU_document_structure_extract
             else nil
             end
           when /^(?:_[1-9]|_[1-9]?\*)\s+/                  #indented and/or bullet paragraph
-            t_o=if t_o=~/^(_(?:[1-9]?\*|[1-9])\s+)(.+)/
+            t_o=if t_o=~/^(_(?:[1-9]?\*|[1-9])\s+)(.+)/m
               tst,obj=$1,$2
               indent=indent_test(tst)
               bullet=bullet_test(tst)
@@ -182,7 +182,7 @@ module SiSU_document_structure_extract
               SiSU_document_structure::Object_para.new.paragraph(h)
             else nil
             end
-          when /^(?:<?:p[bn]>?)\s*$/                       #indented and/or bullet paragraph
+          when /^(?:<?:p[bn]>?)\s*$/
             if t_o =~/^(?:<?:pn>?)\s*$/
               SiSU_document_structure::Object_layout.new.break(Hx[:br_page_new])
             else SiSU_document_structure::Object_layout.new.break(Hx[:br_page])
