@@ -531,8 +531,6 @@ module SiSU_EPUB
           toc_shared << format_txt_obj.center_bold
           segtoc << format_txt_obj.center_bold
         end
-        toc_shared << format_head_toc.copyat
-        segtoc << format_head_toc.copyat
         segtoc << seg_toc_band
         tmp_head=nil
         if defined? @md.prefix_a \
