@@ -82,7 +82,7 @@ module SiSU_EPUB_Format
       else
         ocn_class='ocn'
         @ocn.gsub(/^(\d+|)$/,
-        %{<label class="#{ocn_class}">\\1</label>})
+        %{<label class="#{ocn_class}"><a href="#o\\1" class="lnk#{ocn_class}">\\1</a></label>})
       end
     end
     def name
@@ -142,6 +142,10 @@ module SiSU_EPUB_Format
     color: #003399;
     text-decoration: underline;
   }
+  a.lnkocn:link {
+    color: #777777;
+    text-decoration: none;
+  }
   div {
     margin-left: 0;
     margin-right: 0;
