@@ -192,6 +192,7 @@ module SiSU_EPUB_Tune
       str.gsub!(/þ/u,'&thorn;')   # &#254;
       str.gsub!(/ÿ/u,'&yuml;')    # &#255;
       str.gsub!(/ý/u,'&yacute;')
+      str.gsub!(/<br>/u,'<br />')
       str.gsub(/#{Mx[:nbsp]}/u,'&nbsp;')
       str
     end
@@ -244,6 +245,7 @@ module SiSU_EPUB_Tune
         dob.obj.gsub!(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,'<ins>\1</ins>')
         dob.obj.gsub!(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,'<cite>\1</cite>')
         dob.obj.gsub!(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'<del>\1</del>')
+        dob.obj.gsub!(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,'<tt>\1</tt>') # tt, kbd
         dob.obj.gsub!(/#{Mx[:mk_o]}:name#(\S+?)#{Mx[:mk_c]}/,'')
         dob.obj.gsub!(/^#{Mx[:gl_bullet]}/m,'●&nbsp;&nbsp;')
         dob.obj.gsub!(/#{Mx[:nbsp]}/,'&nbsp;')
@@ -267,8 +269,8 @@ module SiSU_EPUB_Tune
             m,u=/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}(image)/.match(word).captures
           end
           case m
-          when /\.png|\.jpg|\.gif|c=|\d+x\d+/
-            w,h=/(\d+)x(\d+)/.match(m).captures if m =~/\d+x\d+/
+          when /\.png|\.jpg|\.gif|c=|\s\d+x\d+/
+            w,h=/\s(\d+)x(\d+)/.match(m).captures if m =~/\s\d+x\d+/
             w=%{width="#{w}"} if w
             h=%{height="#{h}"} if h
             c=m[/"(.+?)"/m,1]
@@ -331,7 +333,7 @@ module SiSU_EPUB_Tune
               %{<img src="#{@env.url.images_epub}/\\1" naturalsizeflag="0" align="bottom" border="0" />})
           end
           if dob.obj =~/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}(?:#{Mx[:url_o]}\S+?#{Mx[:url_c]}|#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}|image)/
-            @word_mode=dob.obj.scan(/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}(?:#{Mx[:url_o]}\S+?#{Mx[:url_c]}|#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}|image)|(?:#{Mx[:gl_o]}\S+?#{Mx[:gl_c]})+|[^#{Mx[:lnk_o]}#{Mx[:lnk_c]}]+/mu)
+            @word_mode=dob.obj.scan(/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}(?:#{Mx[:url_o]}\S+?#{Mx[:url_c]}|#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}|image)[()\[\]]*[,.;:!?'"]{0,2}|(?:#{Mx[:gl_o]}\S+?#{Mx[:gl_c]})+|[^#{Mx[:lnk_o]}#{Mx[:lnk_c]}]+/mu)
             words=urls(@word_mode)
             dob.obj.gsub!(/.+/m,words)
           end
