@@ -82,7 +82,7 @@ module SiSU_HTML_Format
       else
         ocn_class='ocn'
         @ocn.gsub(/^(\d+|)$/,
-        %{<label class="#{ocn_class}"><a name="#{@ocn}">\\1</a></label>})
+        %{<label class="#{ocn_class}"><a name="#{@ocn}" href="##{@ocn}" class="lnk#{ocn_class}">\\1</a></label>})
       end
     end
     def name
@@ -108,7 +108,17 @@ module SiSU_HTML_Format
       @seg_name_html_tracker=(SiSU_HTML::Source::Seg.new.seg_name_html_tracker || [])
       @index='index'
       @metalink='#metadata'
-      @tocband_scroll,@tocband_segtoc=nil,nil
+    end
+    def doc_types #used in toc & seg_nav_band
+      scroll=seg=''
+      wgt=Widget.new(@md)
+      %{
+<table summary="segment navigation available documents types: toc,doc,pdf,concordance" border="0" cellpadding="3" cellspacing="0">
+<tr>
+<td align="center" bgcolor=#{@vz.color_band2}>
+  #{wgt.manifest}
+  #{wgt.search}
+</tr></table>}
     end
     def rdf
       SiSU_XML_tags::RDF.new(md)
@@ -180,7 +190,7 @@ module SiSU_HTML_Format
   </a>
 </td>}
     end
-    def pdf
+    def pdf #retired 2.7.9
       pdf=if @md.programs[:pdf] \
       and @cf_defaults.cf_0 =~/p/
         %{
@@ -198,7 +208,7 @@ module SiSU_HTML_Format
       else ''
       end
     end
-    def txt
+    def txt #retired 2.7.9
       txt=if @cf_defaults.cf_0 =~/[at]/
         %{
 <td valign=bottom bgcolor=#{@vz.color_band2}>
@@ -209,7 +219,7 @@ module SiSU_HTML_Format
       else ''
       end
     end
-    def epub
+    def epub #retired 2.7.9
       epub=if @cf_defaults.cf_0 =~/e/
         %{
 <td align="center" bgcolor=#{@vz.color_band2}>
@@ -220,7 +230,7 @@ module SiSU_HTML_Format
       else ''
       end
     end
-    def odf
+    def odf #retired 2.7.9
       odf=if @cf_defaults.cf_0 =~/o/
         %{
 <td align="center" bgcolor=#{@vz.color_band2}>
@@ -231,7 +241,7 @@ module SiSU_HTML_Format
       else ''
       end
     end
-    def concordance(text)
+    def concordance(text) #retired 2.7.9
       if @md.concord_make \
       and @md.wc_words < 300000 #max word count for display of concordance here as would now be a large file
   %{<td align="center" bgcolor=#{@vz.color_band2}>
@@ -249,7 +259,6 @@ module SiSU_HTML_Format
     def initialize(md)
       super(md)
       @md=md
-      @tocband_scroll,@tocband_segtoc=make_scroll,make_seg
     end
     def scroll_head_navigation_band
       pdf=if @md.programs[:pdf]
@@ -270,16 +279,10 @@ WOK
 <p />}
     end
     def concordance_navigation_band(type='')
-      if type=~/pdf/
-        @tocband_concordance=make_concordance
-      end
       %{<table summary="concordance navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
 <tr><td width="20%">
  #{@vz.banner_band}
 </td>
-<td width="60%" align="center">
-  #{@tocband_concordance}
-</td>
 <td width="20%" align="right">
   &nbsp;<a href="index.html" target="_top" alt="-&gt;">
       #{@vz.png_nav_toc}
@@ -288,9 +291,6 @@ WOK
 <p />}
     end
     def seg_head_navigation_band(type='')
-      if type=~/pdf/
-        @tocband_segtoc=make_scroll_seg_pdf
-      end
       firstseg=%{<a href="#{@md.fnl[:pre]}#{@md.firstseg}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}" target="_top" alt="-&gt;">
       #{@vz.png_nav_nxt}
     </a>} if @md.firstseg =~/\S+/
@@ -299,14 +299,14 @@ WOK
  #{@vz.banner_band}
 </td>
 <td width="75%" align="center">
-  #{@tocband_segtoc}
+ #{doc_types}
 </td>
 <td width="5%" align="right">
   &nbsp;#{firstseg}&nbsp;
 #{@vz.table_close}
 <p />}
     end
-    def seg_head_navigation_band_bottom(type='')
+    def seg_head_navigation_band_bottom(type='') #retired 2.7.9
       if type=~/pdf/
         @tocband_segtoc=make_scroll_seg_pdf
       end
@@ -330,7 +330,7 @@ WOK
     <a href="#{@md.fn[:manifest]}" target="_top" #{@vz.js_manifest}>#{text}</a>
   </font>}
     end
-    def concordance_link(text)
+    def concordance_link(text) #retired 2.7.9
       if @md.concord_make
   %{<font size=2>
     <a href="#{@md.fn[:concordance]}" target="_top" #{@vz.js_concordance}>
@@ -348,12 +348,8 @@ WOK
 }
       %{<table summary="toc segment and scroll with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
-  #{scroll}
-  #{wgt.seg(@vz.nav_txt_toc_link)}#{wgt.txt}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
-  #{wgt.concordance(@vz.nav_txt_concordance)}
   #{wgt.manifest}
   #{wgt.search}
-  #{wgt.home}
 </tr></table>}
     end
     def make_scroll_seg_pdf
@@ -365,13 +361,9 @@ WOK
 }
       %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
-  #{seg}
-  #{wgt.scroll(@vz.nav_txt_doc_link)}#{wgt.txt}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
 <td align="center" bgcolor=#{@vz.color_band2}>
-  #{wgt.concordance(@vz.nav_txt_concordance)}
   #{wgt.manifest}
   #{wgt.search}
-  #{wgt.home}
 </tr></table>}
     end
     def make_concordance
@@ -379,12 +371,9 @@ WOK
       wgt=Widget.new(@md)
       %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
-  #{wgt.seg(@vz.nav_txt_toc_link)}#{wgt.scroll(@vz.nav_txt_doc_link)}#{wgt.pdf}#{wgt.odf}
 <td align="center" bgcolor=#{@vz.color_band2}>
-  #{wgt.concordance(@vz.nav_txt_concordance)}
   #{wgt.manifest}
   #{wgt.search}
-  #{wgt.home}
 </tr></table>}
     end
     def head
@@ -564,11 +553,6 @@ WOK
 <table summary="toc segment tail" bgcolor=#{@vz.color_band1}>
 <tr><td width="20%">
   #{@vz.banner_band}
-</td>
-<td width="60%">
-  <center>
-    #{@tocband_segtoc}
-  </center>
 </td></tr>
 </table>
 <p>&nbsp;</p>
@@ -733,36 +717,6 @@ WOK
       else ''
       end
     end
-    def doc_types #used in seg_nav_band ###
-      scroll=seg=''
-      wgt=Widget.new(@md)
-      x=if @md.concord_make
-        %{
-<table summary="segment navigation available documents types: toc,doc,pdf,concordance" border="0" cellpadding="3" cellspacing="0">
-<tr>
-  #{wgt.seg(@vz.nav_txt_toc_link)}
-  #{wgt.scroll(@vz.nav_txt_doc_link)}
-  #{wgt.txt}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
-<td align="center" bgcolor=#{@vz.color_band2}>
-  #{wgt.concordance(@vz.nav_txt_concordance)}
-  #{wgt.manifest}
-  #{wgt.search}
-  #{wgt.home}
-</tr></table>}
-      else
-        %{
-<table summary="segment navigation available documents types: toc,doc,pdf,concordance" border="0" cellpadding="3" cellspacing="0">
-<tr>
-  #{wgt.seg(@vz.nav_txt_toc_link)}
-  #{wgt.scroll(@vz.nav_txt_doc_link)}
-  #{wgt.txt}#{wgt.epub}#{wgt.pdf}#{wgt.odf}
-<td align="center" bgcolor=#{@vz.color_band2}>
-  #{wgt.manifest}
-  #{wgt.search}
-  #{wgt.home}
-</tr></table>}
-      end
-    end
     def navigation_table
       %{<table summary="navigation segment table" width=#{@vz.table_width_1} border="0" bgcolor="white" cellpadding="0">
 <tr><th width="#{@@indent['leve_1']}" align="right">
