@@ -117,7 +117,6 @@ module SiSU_Plaintext
       def initialize(data,md,wrap_width)
         @data,@md,@wrap_width=data,md,wrap_width
         @brace_url=SiSU_Viz::Skin.new.url_decoration
-        @vz=SiSU_Env::Get_init.instance.skin
         @tab="\t"
         @@endnotes_=case md.mod.inspect
         when /--footnote/; false
@@ -188,7 +187,9 @@ WOK
       end
       def plaintext_tail
         SiSU_Env::Info_skin.new(@md).select
+        env=SiSU_Env::Info_env.new(@md.fns)
         vz=SiSU_Env::Get_init.instance.skin
+        base_url="#{env.url.root}/#{@md.fnb}"
         generator="Generated by: #{@md.sisu_version[:project]} #{@md.sisu_version[:version]} of #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})"  if @md.sisu_version[:version]
         lastdone="Last Generated on: #{Time.now}"
         rubyv="Ruby version: #{@md.ruby_version}"
@@ -198,18 +199,13 @@ WOK
         end
         @plaintext[:tail] <<<<WOK
 #{@br}
+plaintext (plain text):
+   #{base_url}/#{@md.fn[:plain]}#{@br}
 Other versions of this document: #{@br}
 manifest:
-   #{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:manifest]}#{@br}
-html:
-   #{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:toc]}#{@br}
-pdf:
-   #{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:pdf_p]}
-   #{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:pdf_l]}#{@br}
-plaintext (plain text):
-   #{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:plain]}#{@br}
+   #{base_url}/#{@md.fn[:manifest]}#{@br}
 at:
-   #{vz.url_site}#{@br}
+   #{env.url.root}#{@br}
 
 #{sc}
 * #{generator}
