@@ -295,10 +295,10 @@ module SiSU_TeX
           and not @md.rights.all.empty?
             rght=@md.rights #.author.dup #dup is necessary, else contents of :rights changed
             sp_char=SiSU_TeX_Pdf::Special_characters.new(@md,rght.copyright.all)
-            copymark=if @md.author_copymark; '{\\begin{small}\\raisebox{1ex}{\\copyright}\\end{small}} '
-            else ''
-            end
-            copymark='Copyright {\\begin{small}\\raisebox{1ex}{\\copyright}\\end{small}} '
+            copymark=@md.author_copymark \
+            ? '{\begin{small}\copyright\end{small}} ' \
+            : ''
+            copymark='Copyright {\begin{small}\copyright\end{small}} '
             copyright=sp_char.special_characters_safe.gsub(/^\s*Copyright \(C\)/, copymark)
             @@rights||="\n #{Tex[:backslash]*2}[3]\\ \\linebreak #{copyright}"
           end
@@ -341,10 +341,6 @@ module SiSU_TeX
             if dob.tmp =~/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}/
               dob.tmp=SiSU_TeX_Pdf::Format_text_object.new(@md,dob.tmp).url_str_internal(dob.tmp)
             end
-            if dob.is=='para' \
-            and dob.bullet_
-              dob.tmp='$\txtbullet$~~' + dob.tmp
-            end
           elsif dob.is =='break'
             if dob.obj==Mx[:br_page]; dob.tmp='\newpage'
             elsif dob.obj==Mx[:br_page_new]; dob.tmp='\clearpage'
@@ -406,7 +402,7 @@ module SiSU_TeX
           @lineone=case dob.is
           when /alt|group|verse/
             dob.tmp.gsub!(/#{Mx[:nbsp]}/m,'{~}')
-            dob.tmp.gsub!(/#{Mx[:gl_bullet]}/m,'$\txtbullet$~~')
+            dob.tmp.gsub!(/#{Mx[:gl_bullet]}/m,'$\txtbullet$\hspace{\enspace}') #Bullet environment not used for grouped text, ∴ no hanging indent here
             dob.tmp.gsub!(/#{Mx[:br_nl]}+/m,"\n\n") #match not ideal, but currently not inserting extra newlines anyway
             ocn=SiSU_TeX_Pdf::Format_text_object.new(@md).ocn_display(dob)
             dob.tmp=if dob.is=='group' \
@@ -436,17 +432,19 @@ module SiSU_TeX
           when /code/
             sp_char=SiSU_TeX_Pdf::Special_characters.new(@md,dob.tmp,dob.is)
             dob.tmp=sp_char.special_characters_safe
-            dob.tmp.gsub!(/#{Mx[:nbsp]}/,'{~}')
-            dob.tmp.gsub!(/(?:#{Mx[:br_nl]}\s*)+/,"\n\n") #watch
-            dob.tmp.gsub!(/\n\n\n/m," \\newline\n\n") #watch
+            dob.tmp.gsub!(/#{Mx[:nbsp]}/,'{~}') #dob.tmp.gsub!(/#{Mx[:nbsp]}\s*/,'{~}')
+            dob.tmp.gsub!(/#{Mx[:vline]}/m,'\vline')
+            dob.tmp.gsub!(/ \\( |#{Mx[:br_nl]})/,' {\textbackslash}\1')
+            dob.tmp.gsub!(/#{Mx[:br_nl]}\s*\Z/m,'')
+            dob.tmp.gsub!(/#{Mx[:br_nl]}{2}/,'\newline \\\\\\ ')
+            dob.tmp.gsub!(/#{Mx[:br_nl]}/,' \\\\\\ ')
+            dob.tmp.gsub!(/\n\n\n/m," \\newline\n\n")
             ocn=SiSU_TeX_Pdf::Format_text_object.new(@md).ocn_display(dob)
             dob.tmp = ocn \
             + @tex_ml.paraskip_small \
-            + "\n" \
-            + ' \\begin{scriptsize}' \
-            + "\n" \
+            + '\begin{Codeblock}' \
             + dob.tmp \
-            + '\\end{scriptsize}' \
+            + ' \end{Codeblock}' \
             + "\n" \
             + @tex_ml.paraskip_normal
             dob
@@ -502,11 +500,13 @@ module SiSU_TeX
             and dob.obj=~/Metadata\b/
               h=tst.level4
               metadata=Metadata::TeX_metadata.new(@md).metadata_tex
-              dob.tmp=h.tmp + ' ' + metadata.join(br)
+              dob.tmp=h.tmp + ' ' + '\begin{scriptsize}' + metadata.join(br) + '\end{scriptsize}'
             else dob.tmp='' # dob.tmp={:l =>'',:p =>''}
             end
           when 'para'
-            if dob.indent \
+            if dob.bullet_
+              dob.tmp=tst.bullet
+            elsif dob.indent \
             and dob.indent =~/[1-9]/
               dob.tmp=tst.indent
             else
@@ -566,6 +566,11 @@ module SiSU_TeX
 \\makeatother
 \\chardef\\txtbullet="2022
 \\chardef\\tilde="7E
+%\\chardef\\asterisk="2A
+\\def\\asterisk{{\\rm \\char42} }
+\\definecolor{Light}{gray}{.92}
+\\newcommand{\\Codeblock}[1]{\\normaltext\\raggedright\\small\\ttfamily\\texbackslash#1}
+\\newcommand{\\monosp}[1]{\\normaltext\\ttfamily\\texbackslash#1}
 % \\sloppy
 \\begin{document}
 WOK
@@ -591,19 +596,19 @@ WOK
           else "\n\\author{#{@copymark} \\textnormal{#{author}}}"
           end
         end
-        @tex_file << unless @md.fnb =~/^mail\s*$/; "\n\\date{\\begin{footnotesize} copy @ #{@tex_ml.site} \\end{footnotesize} #{sisu_rc_footnote}}"
-        else                                       "\\date"
+        @tex_file << unless @md.fnb =~/^mail\s*$/; @tex_ml.site
+        else                                       '\date'
         end
         @tex_file <<<<WOK
 \\pagenumbering{roman}\\maketitle
 \\pagestyle{fancy}
 WOK
-        @tex_file << "\\newpage\n"
-        @tex_file << @@rights if defined? @md.rights.all and @md.rights.all #if @orientation =~/landscape/
-        @tex_file << @@prefix_b if defined? @md.creator.prefix_b and @md.creator.prefix_b
-        @tex_file << @tex_ml.sisu_rights
-        @tex_file << (@md.sc_info ? @tex_ml.doc_sc_info : @tex_ml.doc_no_sc_info)
-        @tex_file << @tex_ml.manifest_info
+        if defined? @md.rights.all \
+        and @md.rights.all
+          @tex_file << "\\newpage\n"
+          @tex_file << @@rights
+          @tex_file << @@prefix_b if defined? @md.creator.prefix_b and @md.creator.prefix_b
+        end
         x={}
         x[:l] =<<WOK
 #{@tex_ml.newpage('landscape')}
@@ -658,37 +663,6 @@ WOK
           end
           @tex_file << dob
         end
-        @tex_file << "\n\\newpage\n" # was \\pagebreak\n
-        # kludge ... look again later
-        @tex_file << if @md.doc_skin !~/skin_mail/; @tex_ml.doc_tail
-        else                                        @tex_ml.mail_tail
-        end
-        if defined? @md.lnk \
-        and @md.lnk
-          @md.lnk.each do |l|
-            if l[:say]
-              url=%<#{l[:url]}>
-              url.gsub!(/(?:\\)*([$&~%_#}{^])/,"\\\\\\1")                         #latex special chars
-              s_lnk=l[:say]
-              s_lnk.gsub!(/\s*(#{Mx[:br_line]}|#{Mx[:br_nl]}|#{Mx[:br_paragraph]})\s*/,' \newline ')
-              s_lnk.gsub!(/(?:\\)*([$&~%_#}{^])/,"\\\\\\1")                       #latex special chars
-              if url !~/^\.(\.)?\//
-                s_lnk_url=%<#{@brace_url.tex_open}\\begin{scriptsize}\\url{#{url}}\\end{scriptsize}#{@brace_url.tex_close}>  # note this bit of dereferencing magic
-              else
-                url.gsub!(/\.\.\//,'')
-                s_lnk_url="(#{@tex_ml.site}) \\\\\n" + ' ' +
-                  '\begin{scriptsize}' +
-                  %<\\url\{#{@vz.url_root_http}/#{url}\}> + # note this bit of dereferencing magic
-                  "\\end{scriptsize}"
-              end
-              @tex_file << " #{s_lnk} \\\\\n #{s_lnk_url} \n" unless  @md.doc_skin =~/skin_mail/
-              s_lnk=s_lnk_url=nil
-            end
-          end
-        end
-        @tex_file << " #{@tex_ml.sitename} home: \\\\
-\\begin{bfseries}#{@tex_ml.site}\\end{bfseries}
-"
         @st[:tex][:stmp]||=@md.stmpd
         stamp=@st[:tex][:stmp] if @st[:tex][:stmp]
         if stamp
@@ -711,7 +685,7 @@ WOK
           or @md.mod.inspect =~/--no-ocn/ \
           or not dob.ocn_
             ''
-          else 
+          else
             tags=''
             #[keep] code that follows inserts "name tags" as hypertargets, currently using ocn (converting nametags to ocn) for internal linking, related code: |texpdf_format.rb|@|uses nametags directly|
             #if dob.tags.length > 0 # insert tags "hypertargets"
